Fix Javadoc and rename a test method to explain behavior correctly

Change-Id: Ib992c68de5ce9129ca24621604ead2bfc2add848
diff --git a/core/common/src/test/java/org/onosproject/codec/impl/CriterionJsonMatcher.java b/core/common/src/test/java/org/onosproject/codec/impl/CriterionJsonMatcher.java
index 40ea708..df0f3c6 100644
--- a/core/common/src/test/java/org/onosproject/codec/impl/CriterionJsonMatcher.java
+++ b/core/common/src/test/java/org/onosproject/codec/impl/CriterionJsonMatcher.java
@@ -464,7 +464,7 @@
     }
 
     /**
-     * Matches an optical signal type criterion object.
+     * Matches an Och signal type criterion object.
      *
      * @param criterion criterion to match
      * @return true if the JSON matches the criterion, false otherwise.
diff --git a/core/common/src/test/java/org/onosproject/codec/impl/CriterionCodecTest.java b/core/common/src/test/java/org/onosproject/codec/impl/CriterionCodecTest.java
index 27d691e..6b3d40a 100644
--- a/core/common/src/test/java/org/onosproject/codec/impl/CriterionCodecTest.java
+++ b/core/common/src/test/java/org/onosproject/codec/impl/CriterionCodecTest.java
@@ -413,10 +413,10 @@
     }
 
     /**
      * Tests optical signal type criterion.
      */
     @Test
-    public void matchOpticalSignalTypeTest() {
+    public void matchOchSignalTypeTest() {
         Criterion criterion = Criteria.matchOchSignalType(OchSignalType.FIXED_GRID);
         ObjectNode result = criterionCodec.encode(criterion, context);
         assertThat(result, matchesCriterion(criterion));
@@ -413,10 +413,10 @@
 
     /**
-     * Tests optical signal type criterion.
+     * Tests Och signal type criterion.
      */
     @Test